@@ -32,7 +32,7 @@ logger = logging.getLogger(__name__)
 LABEL_RE = re.compile('[a-z0-9][a-z0-9\-]*[a-z0-9]')
 RESTRICTED_REGIONS = [
     'us-gov-west-1',
-    'fips-gov-west-1',
+    'fips-us-gov-west-1',
 ]
 
 
